# Offline TTS - macOS

ToolMate v0.2.42+ integrates macOS built-in text-to-speech feature.

# Setup

1. Select "change text-to-speech config" from action menu

2. Select "Say" from available tts options

3. Select a voice

Remarks: Make the selected voice is [downloaded](https://github.com/eliranwong/toolmate/blob/main/package/toolmate/docs/Offline%20TTS%20-%20macOS.md#download-more-voices) on your device.

4. Specify Speed

5. Select "toggle input audio" from action menu, to enable / disable reading input text

6. Select "toggle output audio" from action menu, to enable / disable reading output text

# Download More Voices

1. Launch "Settings" App

2. Go to "Accessibility" > "Live Speech"

<img width="827" alt="mactts1" src="https://github.com/eliranwong/toolmate/assets/25262722/4a69d42e-30df-4a42-ad3a-83fc67d664c9">

3. Go to "Voice" > "Manage Voices"

<img width="765" alt="mactts2" src="https://github.com/eliranwong/toolmate/assets/25262722/fdca4fb3-4c31-4f18-ae6b-078bd209fda7">

4. Click the 'cloud' button, right next to the voice that you want, to start download.

<img width="730" alt="mactts3" src="https://github.com/eliranwong/toolmate/assets/25262722/f567a13b-2830-419d-a8ce-2761cf417ec4">